@@ -195,7 +195,7 @@ class DataSpec(Either):
                 transform=Optional(Instance("bokeh.models.transforms.Transform")),
             ),
             default=default,
-            help=help
+            help=help,
         )
         self.value_type = self._validate_type_param(value_type)
         self.accepts(Instance("bokeh.models.expressions.Expression"), lambda obj: Expr(obj))
@@ -253,7 +253,7 @@ class NumberSpec(DataSpec):
     values by passing ``accept_datetime=False``.
 
     By default, timedelta values are immediately converted to absolute
-    milliseconds.  It is possible to disable processing of timedelta
+    milliseconds. It is possible to disable processing of timedelta
     values by passing ``accept_timedelta=False``
 
     Timedelta values are interpreted as absolute milliseconds.
@@ -276,7 +276,8 @@ class NumberSpec(DataSpec):
 class AlphaSpec(NumberSpec):
 
     _default_help = """\
-    Acceptable values are numbers in 0..1 range (transparent..opaque).
+    Acceptable values are floating-point numbers between 0 and 1 (0 being
+    transparent and 1 being opaque).
     """
 
     def __init__(self, default=1.0, *, help: str | None = None) -> None:
@@ -461,7 +462,7 @@ class UnitsSpec(NumberSpec):
         """
         units_name = base_name + "_units"
         units_props = self._units_type.make_descriptors(units_name)
-        return units_props + [ UnitsSpecPropertyDescriptor(base_name, self, units_props[0]) ]
+        return [*units_props, UnitsSpecPropertyDescriptor(base_name, self, units_props[0])]
 
     def to_serializable(self, obj: HasProps, name: str, val: Any) -> Vectorized:
         val = super().to_serializable(obj, name, val)
@@ -504,7 +505,7 @@ class NullDistanceSpec(DistanceSpec):
     def __init__(self, default=None, units_default="data", *, help: str | None = None) -> None:
         super().__init__(default=default, units_default=units_default, help=help)
         self.value_type = Nullable(Float)
-        self._type_params = [Null()] + self._type_params
+        self._type_params = [Null(), *self._type_params]
 
     def prepare_value(self, cls, name, value):
         try:
