@@ -30,7 +30,6 @@ from typing import (
     Callable,
     ClassVar,
     Generic,
-    List,
     Literal,
     NoReturn,
     Sequence,
@@ -50,6 +49,7 @@ from ..util.dataclasses import (
     entries,
     is_dataclass,
 )
+from ..util.dependencies import uses_pandas
 from ..util.serialization import (
     array_encoding_disabled,
     convert_datetime_type,
@@ -110,7 +110,7 @@ class ArrayRep(TypedDict):
     type: Literal["array"]
     entries: NotRequired[list[AnyRep]]
 
-ArrayRepLike: TypeAlias = Union[ArrayRep, List[AnyRep]]
+ArrayRepLike: TypeAlias = Union[ArrayRep, list[AnyRep]]
 
 class SetRep(TypedDict):
     type: Literal["set"]
@@ -455,14 +455,17 @@ class Serializer:
             return self._encode_bool(bool(obj))
 
         # avoid importing pandas here unless it is actually in use
-        module = type(obj).__module__
-        if module is not None and module.startswith("pandas"):
+        if uses_pandas(obj):
             import pandas as pd
             if isinstance(obj, (pd.Series, pd.Index, pd.api.extensions.ExtensionArray)):
                 return self._encode_ndarray(transform_series(obj))
             elif obj is pd.NA:
                 return None
 
+        # handle array libraries that support conversion to a numpy array (e.g. polars, PyTorch)
+        if hasattr(obj, "__array__") and isinstance(arr := obj.__array__(), np.ndarray):
+            return self._encode_ndarray(arr)
+
         self.error(f"can't serialize {type(obj)}")
 
     def error(self, message: str) -> NoReturn:
@@ -471,6 +474,12 @@ class Serializer:
 class DeserializationError(ValueError):
     pass
 
+class UnknownReferenceError(DeserializationError):
+
+    def __init__(self, id: ID) -> None:
+        super().__init__(f"can't resolve reference '{id}'")
+        self.id = id
+
 class Deserializer:
     """ Convert from serializable representations to built-in and custom types. """
 
@@ -566,7 +575,7 @@ class Deserializer:
         if instance is not None:
             return instance
         else:
-            self.error(f"can't resolve reference '{id}'")
+            self.error(UnknownReferenceError(id))
 
     def _decode_symbol(self, obj: SymbolRep) -> float:
         name = obj["name"]
@@ -713,8 +722,11 @@ class Deserializer:
             else:
                 self.error(f"can't resolve type '{type}'")
 
-    def error(self, message: str) -> NoReturn:
-        raise DeserializationError(message)
+    def error(self, error: str | DeserializationError) -> NoReturn:
+        if isinstance(error, str):
+            raise DeserializationError(error)
+        else:
+            raise error
 
 #-----------------------------------------------------------------------------
 # Dev API
