@@ -120,6 +120,7 @@ class figure(Plot, GlyphAPI):
         * :func:`~bokeh.plotting.figure.dot`
         * :func:`~bokeh.plotting.figure.ellipse`
         * :func:`~bokeh.plotting.figure.harea`
+        * :func:`~bokeh.plotting.figure.harea_step`
         * :func:`~bokeh.plotting.figure.hbar`
         * :func:`~bokeh.plotting.figure.hex`
         * :func:`~bokeh.plotting.figure.hex_tile`
@@ -152,6 +153,7 @@ class figure(Plot, GlyphAPI):
         * :func:`~bokeh.plotting.figure.triangle_dot`
         * :func:`~bokeh.plotting.figure.triangle_pin`
         * :func:`~bokeh.plotting.figure.varea`
+        * :func:`~bokeh.plotting.figure.varea_step`
         * :func:`~bokeh.plotting.figure.vbar`
         * :func:`~bokeh.plotting.figure.wedge`
         * :func:`~bokeh.plotting.figure.x`
@@ -252,7 +254,7 @@ class figure(Plot, GlyphAPI):
                 A NumPy array of x-coordinates to bin into hexagonal tiles.
 
             y (array[float]) :
-                A NumPy array of y-coordinates to bin into hexagonal tiles
+                A NumPy array of y-coordinates to bin into hexagonal tiles.
 
             size (float) :
                 The size of the hexagonal tiling to use. The size is defined as
@@ -294,7 +296,7 @@ class figure(Plot, GlyphAPI):
 
         Any additional keyword arguments are passed to :func:`hex_tile`.
 
-        Returns
+        Returns:
             (Glyphrender, DataFrame)
                 A tuple with the ``HexTile`` renderer generated to display the
                 binning, and a Pandas ``DataFrame`` with columns ``q``, ``r``,
@@ -733,7 +735,7 @@ def markers():
     '''
     print("Available markers: \n\n - " + "\n - ".join(list(MarkerType)))
     print()
-    print("Shortcuts: \n\n" + "\n".join(" %r: %s" % item for item in _MARKER_SHORTCUTS.items()))
+    print("Shortcuts: \n\n" + "\n".join(f" {short!r}: {name}" for (short, name) in _MARKER_SHORTCUTS.items()))
 
 #-----------------------------------------------------------------------------
 # Dev API
