@@ -42,7 +42,6 @@ from typing import (
     TYPE_CHECKING,
     Callable,
     ClassVar,
-    Dict,
     Literal,
     Protocol,
     TypedDict,
@@ -69,8 +68,8 @@ if TYPE_CHECKING:
 # Globals and constants
 # -----------------------------------------------------------------------------
 
-DEFAULT_SERVER_HOST = "localhost"
-DEFAULT_SERVER_PORT = 5006
+DEFAULT_SERVER_HOST = settings.default_server_host()
+DEFAULT_SERVER_PORT = settings.default_server_port()
 
 def server_url(host: str | None = None, port: int | None = None, ssl: bool = False) -> str:
     protocol = "https" if ssl else "http"
@@ -99,7 +98,7 @@ class ComponentDefs(TypedDict):
 # Dev API
 # -----------------------------------------------------------------------------
 
-Hashes: TypeAlias = Dict[str, str]
+Hashes: TypeAlias = dict[str, str]
 
 _SRI_HASHES: dict[str, Hashes] | None = None
 
@@ -352,7 +351,7 @@ class Resources:
         if self.mode not in get_args(BaseMode):
             raise ValueError(
                 "wrong value for 'mode' parameter, expected "
-                f"'inline', 'cdn', 'server(-dev)', 'relative(-dev)' or 'absolute(-dev)', got {mode}"
+                f"'inline', 'cdn', 'server(-dev)', 'relative(-dev)' or 'absolute(-dev)', got {mode}",
             )
 
         if root_dir and not self.mode.startswith("relative"):
@@ -416,6 +415,13 @@ class Resources:
 
     __str__ = __repr__
 
+    @classmethod
+    def build(cls, resources: ResourcesLike | None = None) -> Resources:
+        if isinstance(resources, Resources):
+            return resources
+        else:
+            return Resources(mode=settings.resources(resources))
+
     # Properties --------------------------------------------------------------
 
     @property
@@ -641,8 +647,11 @@ def _get_cdn_urls(version: str | None = None, minified: bool = True) -> Urls:
     return result
 
 
-def _get_server_urls(root_url: str, minified: bool = True,
-        path_versioner: PathVersioner | None = None) -> Urls:
+def _get_server_urls(
+    root_url: str = DEFAULT_SERVER_HTTP_URL,
+    minified: bool = True,
+    path_versioner: PathVersioner | None = None,
+) -> Urls:
     _minified = ".min" if minified else ""
 
     def mk_url(comp: str, kind: Kind) -> str:
