@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -126,7 +126,6 @@ from typing import (
     Generic,
     Literal,
     Sequence,
-    Type,
     TypeVar,
     Union,
     cast,
@@ -328,7 +327,7 @@ class _Unset: pass
 
 T = TypeVar("T")
 
-Unset: TypeAlias = Union[T, Type[_Unset]]
+Unset: TypeAlias = Union[T, type[_Unset]]
 
 def is_dev() -> bool:
     return convert_bool(os.environ.get("BOKEH_DEV", False))
@@ -433,12 +432,15 @@ class PrioritizedSetting(Generic[T]):
 
         raise RuntimeError(f"No configured value found for setting {self._name!r}")
 
-    def __get__(self, instance: Any, owner: Type[Any]) -> PrioritizedSetting[T]:
+    def __get__(self, instance: Any, owner: type[Any]) -> PrioritizedSetting[T]:
         return self
 
     def __set__(self, instance: Any, value: str | T) -> None:
         self.set_value(value)
 
+    def __delete__(self, instance: Any) -> None:
+        self.unset_value()
+
     def set_value(self, value: str | T) -> None:
         ''' Specify a value for this setting programmatically.
 
@@ -565,6 +567,15 @@ class Settings:
     See the :class:`~bokeh.resources.Resources` class reference for full details.
     """)
 
+    chromedriver_path: PrioritizedSetting[str | None] = PrioritizedSetting("chromedriver_path", "BOKEH_CHROMEDRIVER_PATH", default=None, help="""
+    The name of or full path to chromedriver's executable.
+
+    This is used to allow ``bokeh.io.export`` to work on systems that use a
+    different name for ``chromedriver``, like ``chromedriver-binary`` or
+    ``chromium.chromedriver`` (or its variant, which is used for example
+    by Snap package manager; see https://snapcraft.io/).
+    """)
+
     cookie_secret: PrioritizedSetting[str | None] = PrioritizedSetting("cookie_secret", "BOKEH_COOKIE_SECRET", default=None, help="""
     Configure the ``cookie_secret`` setting in Tornado. This value is required
     if you use ``get_secure_cookie`` or ``set_secure_cookie``.  It should be a
@@ -683,6 +694,14 @@ class Settings:
     See the :class:`~bokeh.resources.Resources` class reference for full details.
     """)
 
+    default_server_host: PrioritizedSetting[str] = PrioritizedSetting("default_server_host", "BOKEH_DEFAULT_SERVER_HOST", default="localhost", help="""
+    Allows to define the default host used by Bokeh's server and resources.
+    """)
+
+    default_server_port: PrioritizedSetting[int] = PrioritizedSetting("default_server_port", "BOKEH_DEFAULT_SERVER_PORT", default=5006, help="""
+    Allows to define the default port used by Bokeh's server and resources.
+    """)
+
     secret_key: PrioritizedSetting[str | None] = PrioritizedSetting("secret_key", "BOKEH_SECRET_KEY", default=None, help="""
     A long, cryptographically-random secret unique to a Bokeh deployment.
     """)
@@ -808,10 +827,10 @@ settings = Settings()
 
 _secret_key = settings.secret_key()
 if _secret_key is not None and len(_secret_key) < 32:
-    import warnings
-    warnings.warn("BOKEH_SECRET_KEY is recommended to have at least 32 bytes of entropy chosen with a cryptographically-random algorithm")
+    from .util.warnings import warn
+    warn("BOKEH_SECRET_KEY is recommended to have at least 32 bytes of entropy chosen with a cryptographically-random algorithm")
 del _secret_key
 
 if settings.sign_sessions() and settings.secret_key() is None:
-    import warnings
-    warnings.warn("BOKEH_SECRET_KEY must be set if BOKEH_SIGN_SESSIONS is set to True")
+    from .util.warnings import warn
+    warn("BOKEH_SECRET_KEY must be set if BOKEH_SIGN_SESSIONS is set to True")
